# Loading weekly data for wig20 and its components from stooq
################################################################################
rm(list=ls())

require(zoo)
require(xts)
require(lubridate)

# loading weakly wig data
# filename <- "https://stooq.pl/q/d/l/?s=wig&i=w" for weekly data
filename <- "https://stooq.pl/q/d/l/?s=wig&i=d"
x        <- read.csv(filename)
y        <- zoo(x$Zamkniecie, as.Date(x$Data))
data0    <- y

# adding the data for wig20 stocks
# for actual tickers look at: https://stooq.pl/q/i/?s=wig20
# ALE Allegro
# ALR Alior
# BDX Budimex
# CDR	CDPROJEKT	
# CPS	CYFRPLSAT	
# DNP	DINOPL
# JSW	JSW	
# KGH	KGHM	
# KRU KRUK
# KTY	KETY	
# LPP	LPP	
# MBK MBANK	
# OPL	ORANGEPL	
# PCO PEPCO
# PEO	PEKAO	
# PGE	PGE		
# PKN	PKNORLEN	
# PKO	PKOBP	
# PZU	PZU	
# SPL	SANPL	

tickers = c("ale","alr","bdx","cdr","cps","dnp","jsw","kgh","kru","kty","lpp","mbk","opl","pco","peo","pge","pkn","pko","pzu","spl") 
for(tick in tickers){
  filename <- paste("https://stooq.pl/q/d/l/?s=",tick,"&i=d", sep = "")
  x        <- read.csv(filename)
  y        <- zoo(x$Zamkniecie, as.Date(x$Data))
  data0    <- merge(data0,y)
}            
names(data0) <- c("wig",tickers)
data         <- window(data0,start = last(index(data0))-years(10))

# writting to csv
save(data,file="wig20.Rdata")
write.csv(as.data.frame(data),file="wig20.csv")

# Exchange rates
# see https://stooq.pl/t/?i=60
filename <- "https://stooq.pl/q/d/l/?s=eurpln&i=d"
x        <- read.csv(filename)
y        <- zoo(x$Zamkniecie, as.Date(x$Data))
data0    <- y

tickers = c("AUDPLN","JPYPLN","KRWPLN","NZDPLN","CHFPLN","CZKPLN","GBPPLN","HUFPLN","NOKPLN","RONPLN","SEKPLN","CADPLN","USDPLN")	

for(tick in tickers){
  filename <- paste("https://stooq.pl/q/d/l/?s=",tolower(tick),"&i=d", sep = "")
  x        <- read.csv(filename)
  y        <- zoo(x$Zamkniecie, as.Date(x$Data))
  data0    <- merge(data0,y)
}            
names(data0) <- c("EURPLN",tickers)

data         <- window(data0,start = last(index(data0))-years(10))

# writting to csv
save(data,file="PLN.Rdata")
write.csv(as.data.frame(data),file="PLN.csv")